@@ -18,7 +18,7 @@ GraphGeodesic <- function(x, nTip = length(x$tip.label), log = FALSE,
   x <- Preorder(x)
   edge <- x$edge - 1L
   nNode <- x$Nnode
-  ret <- .Call(if (isTRUE(log)) "LOG_GRAPH_GEODESIC" else "GRAPH_GEODESIC",
+  ret <- .Call(if (isTRUE(log)) `LOG_GRAPH_GEODESIC` else `GRAPH_GEODESIC`,
                n_tip = as.integer(nTip),
                n_node = as.integer(nNode),
                parent = as.integer(edge[, 1]),
